@@ -18,7 +18,7 @@ use crate::tensor_util::TorchDeviceDtype;
 
 #[pyfunction]
 pub fn cast_circuit(circ: CircuitRc, device_dtype: &TorchDeviceDtype) -> CircuitRc {
-    deep_map_unwrap(&circ, &|circ| match circ {
+    deep_map_unwrap(&circ, |circ| match circ {
         Circuit::ArrayConstant(node) => ArrayConstant::nrc(
             device_dtype.cast_tensor(node.value.clone()),
             node.name_cloned(),
@@ -104,7 +104,7 @@ pub fn get_leaves(circuit: CircuitRc) -> Vec<CircuitRc> {
 #[pyfunction]
 pub fn get_all_einsum_specs(circuit: CircuitRc) -> Vec<EinsumSpec> {
     let mut result: Vec<EinsumSpec> = vec![];
-    visit_circuit(&circuit, &mut |c| {
+    visit_circuit(&**circuit, |c| {
         if let Circuit::Einsum(node) = c {
             result.push(node.get_spec());
         }
@@ -115,7 +115,7 @@ pub fn get_all_einsum_specs(circuit: CircuitRc) -> Vec<EinsumSpec> {
 #[pyfunction]
 pub fn toposort_circuit(circuit: CircuitRc) -> Vec<CircuitRc> {
     let mut num_refs: HashMap<CircuitRc, usize> = HashMap::new();
-    visit_circuit(&circuit, &mut |c| {
+    visit_circuit(&circuit, |c| {
         for child in c.children() {
             *num_refs.entry(child).or_insert(0) += 1;
         }
@@ -136,7 +136,7 @@ pub fn toposort_circuit(circuit: CircuitRc) -> Vec<CircuitRc> {
     result
 }
 
-pub fn deep_map_pass_up<F, T>(circuit: &Circuit, f: &mut F) -> (CircuitRc, T)
+pub fn deep_map_pass_up<F, T>(circuit: &Circuit, mut f: F) -> (CircuitRc, T)
 where
     T: Clone,
     F: FnMut(&Circuit, Vec<T>) -> (CircuitRc, T),
@@ -156,7 +156,7 @@ where
 
 #[pyfunction]
 pub fn replace_all_randn_seeded(circuit: CircuitRc) -> CircuitRc {
-    deep_map_unwrap(&circuit, &mut |node| match node {
+    deep_map_unwrap(&circuit, |node| match node {
         Circuit::ArrayConstant(ac) => ArrayConstant::randn_named_seeded(
             ac.info().shape.clone(),
             ac.name_cloned(),
