@@ -96,7 +96,7 @@ impl CircuitNode for Einsum {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
@@ -530,7 +530,7 @@ impl CircuitNode for Add {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
@@ -708,7 +708,7 @@ impl CircuitNode for Rearrange {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
@@ -861,7 +861,7 @@ impl CircuitNode for Index {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
@@ -988,7 +988,7 @@ impl CircuitNode for Concat {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
@@ -1178,7 +1178,7 @@ impl CircuitNode for Scatter {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
