@@ -1,9 +1,10 @@
 use crate::pyo3_prelude::*;
 use std::{collections::HashMap, iter::zip};
 
+use super::circuit_optimizer::optimize_and_evaluate;
 use super::{
-    CachedCircuitInfo, Circuit, CircuitConstructionError, CircuitNode, CircuitNodeAutoName,
-    CircuitRc, HashBytes,
+    Add, ArrayConstant, CachedCircuitInfo, Circuit, CircuitConstructionError, CircuitNode,
+    CircuitNodeAutoName, CircuitRc, Einsum, HashBytes,
 };
 use crate::py_types::{GENERALFUNCTIONS, PY_NONE};
 use crate::{
@@ -248,7 +249,7 @@ impl CircuitNode for GeneralFunction {
 
     fn map_children_enumerate<'a, F, E>(
         &'a self,
-        f: &mut F,
+        mut f: F,
     ) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
