@@ -47,12 +47,21 @@ pub fn named_axes_backward<T: CircuitNode + Clone>(
 #[pyfunction]
 pub fn propagate_named_axes(circuit: CircuitRc, named_axes: NamedAxes) -> CircuitRc {
     cached_lambda! {
-        let mut recurse = |circ: Circuit,axes:NamedAxes| -> CircuitRc = {
-            let new_out_axes = merge_named_axes(&circ.info().named_axes,&axes);
+        let mut recurse = |circ: Circuit, axes: NamedAxes| -> CircuitRc = {
+            let new_out_axes = merge_named_axes(&circ.info().named_axes, &axes);
             let new_child_axes = named_axes_backward(&circ, &new_out_axes);
-            let child_axis_names:HashMap<HashBytes,NamedAxes>=zip(circ.children(),new_child_axes).map(|(c,a)|(c.info().hash,a)).collect();
+            let child_axis_names: HashMap<HashBytes, NamedAxes> = zip(circ.children(), new_child_axes)
+                .map(|(c, a)| (c.info().hash, a))
+                .collect();
 
-            set_named_axes(&circ,new_out_axes).map_children_unwrap(&mut |childy|recurse(childy.clone(),child_axis_names[&childy.info().hash].clone())).rc()
+            set_named_axes(&circ, new_out_axes)
+                .map_children_unwrap(|childy| {
+                    recurse(
+                        childy.clone(),
+                        child_axis_names[&childy.info().hash].clone(),
+                    )
+                })
+                .rc()
         };
     }
     recurse((**circuit).clone(), named_axes)
