@@ -1,12 +1,11 @@
 use std::collections::HashMap;
 
 use super::{
-    circuit_utils::{count_nodes, total_flops},
+    circuit_utils::{count_nodes, toposort_circuit, total_flops},
     repr::ReprWrapper,
     Circuit, CircuitNode, CircuitNodeUnion, CircuitRc, HashBytes,
 };
 use crate::circuit::repr::RustRepr;
-use crate::toposort_circuit;
 use num_bigint::BigUint;
 use pyo3::pyfunction;
 
