@@ -1,49 +1,6 @@
 #![feature(core_intrinsics)]
 #![feature(map_first_last)]
 
-use circuit::algebraic_rewrite::{
-    add_collapse_scalar_inputs, add_deduplicate, add_elim_zeros, add_flatten_once,
-    add_make_broadcasts_explicit, add_pull_removable_axes, concat_elim_identity,
-    concat_merge_uniform, concat_pull_removable_axes, deep_optimize_einsums, distribute,
-    distribute_all, einsum_elim_identity, einsum_elim_zero, einsum_flatten_once,
-    einsum_merge_scalars, einsum_nest_optimize, einsum_nest_path, einsum_of_permute_merge,
-    einsum_pull_removable_axes, generalfunction_pull_removable_axes, index_elim_identity,
-    index_fuse, index_merge_scalar, index_split_axes, permute_of_einsum_merge, push_down_index,
-    rearrange_elim_identity, rearrange_fuse, rearrange_merge_scalar, remove_add_few_input,
-};
-use circuit::batching::{batch_inputs_axis_len, batch_largest};
-use circuit::canonicalize::{canonicalize_node_py, deep_canonicalize};
-use circuit::circuit_manipulation::{
-    deep_map_preorder_py, deep_map_py, filter_nodes_py, path_get, replace_nodes, update_nodes_py,
-    update_path_py,
-};
-use circuit::circuit_optimizer::{
-    optimize_and_evaluate, optimize_and_evaluate_many, optimize_circuit,
-};
-use circuit::circuit_utils::{
-    cast_circuit, count_nodes, toposort_circuit, total_arrayconstant_size, total_flops,
-};
-use circuit::compiler_heuristics::{deep_maybe_distribute_py, maybe_distribute};
-use circuit::compiler_strip::strip_names;
-use circuit::concat_rewrite::{
-    add_pull_concat, concat_drop_size_zero, concat_fuse, einsum_pull_concat,
-    generalfunction_pull_concat, index_concat_drop_unreached, split_to_concat,
-};
-use circuit::deep_rewrite::{
-    compiler_simp_py, compiler_simp_step_py, compiler_simp_until_same, deep_heuristic_nest_adds,
-    deep_pull_concat, deep_pull_concat_messy, deep_push_down_index,
-};
-use circuit::diag_rewrite::{add_pull_diags, einsum_push_down_trace};
-use circuit::flat_concat;
-use circuit::named_axes::{propagate_named_axes, set_named_axes_py};
-use circuit::scatter_rewrite::{
-    add_pull_scatter, einsum_pull_scatter, index_einsum_to_scatter, scatter_elim_identity,
-    scatter_pull_removable_axes, scatter_to_concat,
-};
-use circuit::scheduled_execution::{scheduled_evaluate, PyOOMError};
-use opt_einsum::optimize_einsum_spec_cached;
-use pyo3::exceptions::PyValueError;
-
 /// reexport
 pub use pyo3;
 pub use uuid;
@@ -90,7 +47,49 @@ pub mod util;
 #[cfg(feature = "real-pyo3")]
 #[pymodule]
 fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
-    use circuit::algebraic_rewrite::concat_repeat_to_rearrange;
+    use circuit::algebraic_rewrite::{
+        add_collapse_scalar_inputs, add_deduplicate, add_elim_zeros, add_flatten_once,
+        add_make_broadcasts_explicit, add_pull_removable_axes, concat_elim_identity,
+        concat_merge_uniform, concat_pull_removable_axes, concat_repeat_to_rearrange,
+        deep_optimize_einsums, distribute, distribute_all, einsum_elim_identity, einsum_elim_zero,
+        einsum_flatten_once, einsum_merge_scalars, einsum_nest_optimize, einsum_nest_path,
+        einsum_of_permute_merge, einsum_pull_removable_axes, generalfunction_pull_removable_axes,
+        index_elim_identity, index_fuse, index_merge_scalar, index_split_axes,
+        permute_of_einsum_merge, push_down_index, rearrange_elim_identity, rearrange_fuse,
+        rearrange_merge_scalar, remove_add_few_input,
+    };
+    use circuit::batching::{batch_inputs_axis_len, batch_largest};
+    use circuit::canonicalize::{canonicalize_node_py, deep_canonicalize};
+    use circuit::circuit_manipulation::{
+        deep_map_preorder_py, deep_map_py, filter_nodes_py, path_get, replace_nodes,
+        update_nodes_py, update_path_py,
+    };
+    use circuit::circuit_optimizer::{
+        optimize_and_evaluate, optimize_and_evaluate_many, optimize_circuit,
+    };
+    use circuit::circuit_utils::{
+        cast_circuit, count_nodes, toposort_circuit, total_arrayconstant_size, total_flops,
+    };
+    use circuit::compiler_heuristics::{deep_maybe_distribute_py, maybe_distribute};
+    use circuit::compiler_strip::strip_names;
+    use circuit::concat_rewrite::{
+        add_pull_concat, concat_drop_size_zero, concat_fuse, einsum_pull_concat,
+        generalfunction_pull_concat, index_concat_drop_unreached, split_to_concat,
+    };
+    use circuit::deep_rewrite::{
+        compiler_simp_py, compiler_simp_step_py, compiler_simp_until_same,
+        deep_heuristic_nest_adds, deep_pull_concat, deep_pull_concat_messy, deep_push_down_index,
+    };
+    use circuit::diag_rewrite::{add_pull_diags, einsum_push_down_trace};
+    use circuit::flat_concat;
+    use circuit::named_axes::{propagate_named_axes, set_named_axes_py};
+    use circuit::scatter_rewrite::{
+        add_pull_scatter, einsum_pull_scatter, index_einsum_to_scatter, scatter_elim_identity,
+        scatter_pull_removable_axes, scatter_to_concat,
+    };
+    use circuit::scheduled_execution::{scheduled_evaluate, PyOOMError};
+    use opt_einsum::optimize_einsum_spec_cached;
+    use pyo3::exceptions::PyValueError;
 
     // we assume throughout the codebase that usize is 8 bytes, and otherwise error here
     if !core::mem::size_of::<usize>() == 8 {
