@@ -105,6 +105,14 @@ macro_rules! pycall {
     ($f:ident,$args:expr) => {
         Python::with_gil(|py| $f.call(py, $args, None).unwrap().extract(py).unwrap())
     };
+    ($f:ident,$args:expr,$err_type:ty) => {
+        Python::with_gil(|py| {
+            $f.call(py, $args, None)
+                .map_err(|z| <$err_type>::from(z))?
+                .extract(py)
+                .map_err(|z| <$err_type>::from(z))
+        })
+    };
 }
 
 macro_rules! generate_extra_py_ops {
